
from . import match_all
import pytest


def test_match_all():
  matches = [x.groups() for x in match_all(r'(\d+)([A-Z]+)', '30D2A53BO')]
  assert matches == [('30', 'D'), ('2', 'A'), ('53', 'BO')]

  matches = [x.group(0) for x in match_all(r'\d{2}', '1234567890')]
  assert matches == ['12', '34', '56', '78', '90']

  with pytest.raises(match_all.Error) as excinfo:
    list(match_all(r'\d{2}', '123456789'))
  assert excinfo.value.string == '123456789'
  assert excinfo.value.endpos == 8



# This file was automatically generated by Shore. Do not edit manually.
# For more information on Shore see https://pypi.org/project/nr.shore/

from __future__ import print_function
import io
import os
import re
import setuptools
import sys

with io.open('src/nr/utils/re/__init__.py', encoding='utf8') as fp:
  version = re.search(r"__version__\s*=\s*'(.*)'", fp.read()).group(1)

readme_file = 'README.md'
if os.path.isfile(readme_file):
  with io.open(readme_file, encoding='utf8') as fp:
    long_description = fp.read()
else:
  print("warning: file \"{}\" does not exist.".format(readme_file), file=sys.stderr)
  long_description = None

requirements = []
extras_require = {}
extras_require['test'] = ['pytest']
tests_require = []
tests_require = ['pytest']

setuptools.setup(
  name = 'nr.utils.re',
  version = version,
  author = 'Niklas Rosenstein',
  author_email = 'rosensteinniklas@gmail.com',
  description = 'This module provides some utility functions for applying regular expressions.',
  long_description = long_description,
  long_description_content_type = 'text/markdown',
  url = 'https://git.niklasrosenstein.com/NiklasRosenstein/nr-python-libs',
  license = 'MIT',
  packages = setuptools.find_packages('src', ['test', 'test.*', 'docs', 'docs.*']),
  package_dir = {'': 'src'},
  include_package_data = True,
  install_requires = requirements,
  extras_require = extras_require,
  tests_require = tests_require,
  python_requires = None, # TODO: '>=2.7,<3.0.0|>=3.4,<4.0.0',
  data_files = [],
  entry_points = {},
  cmdclass = {},
  keywords = [],
  classifiers = [],
  options = {
    'bdist_wheel': {
      'universal': True,
    },
  },
)
